@@ -53,7 +53,9 @@ class GitProject:
         config_path = os.path.join(GitProject.git_path(), 'config')
         config = configparser.ConfigParser()
         config.read(config_path)
-        parse = urlparse(config.get('remote "origin"', "url"))
+        url = config.get('remote "origin"', "url").replace("git@", '').replace(":", "/")
+        url = 'http://' + url if "http" not in url else url
+        parse = urlparse(url)
         return parse
 
     @staticmethod
